"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = require("../hooks/http");
const instrumentation_http_1 = require("@opentelemetry/instrumentation-http");
const axios_1 = __importDefault(require("axios"));
const wrapper_1 = require("../wrapper");
let metadata;
const fetchMetadataUri = () => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const metadataUri = process.env['ECS_CONTAINER_METADATA_URI'];
        if (metadataUri) {
            return axios_1.default.get(metadataUri);
        }
        else {
            console.warn('Missing ECS metadata...');
            return Promise.resolve(undefined);
        }
    }
    catch (e) {
        return undefined;
    }
});
fetchMetadataUri().then((res) => {
    metadata = res === null || res === void 0 ? void 0 : res.data;
});
class LumigoHttpInstrumentation {
    constructor(lumigoToken, endPoint) {
        return new instrumentation_http_1.HttpInstrumentation({
            ignoreOutgoingUrls: process.env['ECS_CONTAINER_METADATA_URI']
                ? [process.env['ECS_CONTAINER_METADATA_URI'], endPoint, wrapper_1.LUMIGO_ENDPOINT]
                : [endPoint, wrapper_1.LUMIGO_ENDPOINT],
            applyCustomAttributesOnSpan: (span) => {
                if (metadata)
                    span.setAttribute('metadata', JSON.stringify(metadata));
                if (lumigoToken)
                    span.setAttribute('lumigoToken', lumigoToken);
            },
            requestHook: http_1.HttpHooks.requestHook,
            responseHook: http_1.HttpHooks.responseHook,
        });
    }
}
exports.default = LumigoHttpInstrumentation;
//# sourceMappingURL=LumigoHttpInstrumentation.js.map