"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAwsServiceData = exports.getAwsServiceFromHost = exports.AWS_PARSED_SERVICES = exports.EXTERNAL_SERVICE = void 0;
const aws_1 = require("../parsers/aws");
exports.EXTERNAL_SERVICE = 'external';
exports.AWS_PARSED_SERVICES = ['dynamodb', 'sns', 'lambda', 'sqs', 'kinesis', 'events'];
const getAwsServiceFromHost = (host = '') => {
    const service = host.split('.')[0];
    if (exports.AWS_PARSED_SERVICES.includes(service)) {
        return service;
    }
    if (host.includes('execute-api'))
        return 'apigw';
    return exports.EXTERNAL_SERVICE;
};
exports.getAwsServiceFromHost = getAwsServiceFromHost;
const getAwsServiceData = (requestData, responseData, span) => {
    const { host } = requestData;
    const awsService = (0, exports.getAwsServiceFromHost)(host);
    switch (awsService) {
        case 'dynamodb':
            return (0, aws_1.dynamodbParser)(requestData);
        case 'sns':
            return (0, aws_1.snsParser)(requestData, responseData);
        case 'lambda':
            return (0, aws_1.lambdaParser)(requestData, responseData);
        case 'sqs':
            return (0, aws_1.sqsParser)(requestData, responseData);
        case 'kinesis':
            return (0, aws_1.kinesisParser)(requestData, responseData);
        case 'apigw':
            return (0, aws_1.apigwParser)(requestData, responseData);
        case 'events':
            return (0, aws_1.eventBridgeParser)(requestData, responseData);
        default:
            return (0, aws_1.awsParser)(requestData, responseData);
    }
};
exports.getAwsServiceData = getAwsServiceData;
//# sourceMappingURL=awsSpan.js.map